(activity* state activity-id)Retrieves an activity with a given id, throwing an exception if missing
Retrieves an activity with a given id, throwing an exception if missing
(activity-subscribers state activity-type)Returns a list of ids for the peers that have subscribed for a given activity type
Returns a list of ids for the peers that have subscribed for a given activity type
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |